@@ -308,7 +308,6 @@ def iw2tau(gf_iw, beta, moments=(1.,), fourier=iw2tau_dft, n_fit=0):
     --------
     iw2tau_dft : Back-end: plain implementation of Fourier transform
     iw2tau_dft_soft : Back-end: Fourier transform with artificial softening of oszillations
-
     pole_gf_from_moments : Function handling the given `moments`
 
     Notes
@@ -476,7 +475,7 @@ def tau2iv_ft_lin(gf_tau, beta):
 
     :math:`G(τ)` is approximated by a linear spline. A linear approximation was
     chosen to be able to integrate noisy functions. Information on oscillatory
-    integrations can be found e.g. in [filon1928]_ and [iserles]_.
+    integrations can be found e.g. in [filon1930]_ and [iserles2006]_.
 
     Parameters
     ----------
@@ -497,10 +496,13 @@ def tau2iv_ft_lin(gf_tau, beta):
 
     References
     ----------
-    .. [filon1928] L.N. Filon, On a quadrature formula for trigonometric integrals,
-       Proc. Roy. Soc. Edinburgh 49 (1928) 38-47.
-    .. [iserles] A. Iserles, S.P. Nørsett, and S. Olver, Highly oscillatory
-       quadrature: The story so far,
+    .. [filon1930] Filon, L. N. G. III.—On a Quadrature Formula for
+       Trigonometric Integrals. Proc. Roy. Soc. Edinburgh 49, 38–47 (1930).
+       https://doi.org/10.1017/S0370164600026262
+    .. [iserles2006] Iserles, A., Nørsett, S. P. & Olver, S. Highly Oscillatory
+       Quadrature: The Story so Far. in Numerical Mathematics and Advanced
+       Applications (eds. de Castro, A. B., Gómez, D., Quintela, P. & Salgado, P.)
+       97–118 (Springer, 2006). https://doi.org/10.1007/978-3-540-34288-5_6
        http://www.sam.math.ethz.ch/~hiptmair/Seminars/OSCINT/INO06.pdf
 
     Examples
@@ -741,7 +743,7 @@ def tau2iw_ft_lin(gf_tau, beta):
 
     :math:`G(τ)` is approximated by a linear spline. A linear approximation was
     chosen to be able to integrate noisy functions. Information on oscillatory
-    integrations can be found e.g. in [filon1928]_ and [iserles]_.
+    integrations can be found e.g. in [filon1930]_ and [iserles2006]_.
 
     Parameters
     ----------
@@ -762,10 +764,13 @@ def tau2iw_ft_lin(gf_tau, beta):
 
     References
     ----------
-    .. [filon1928] L.N. Filon, On a quadrature formula for trigonometric integrals,
-       Proc. Roy. Soc. Edinburgh 49 (1928) 38-47.
-    .. [iserles] A. Iserles, S.P. Nørsett, and S. Olver, Highly oscillatory
-       quadrature: The story so far,
+    .. [filon1930] Filon, L. N. G. III.—On a Quadrature Formula for
+       Trigonometric Integrals. Proc. Roy. Soc. Edinburgh 49, 38–47 (1930).
+       https://doi.org/10.1017/S0370164600026262
+    .. [iserles2006] Iserles, A., Nørsett, S. P. & Olver, S. Highly Oscillatory
+       Quadrature: The Story so Far. in Numerical Mathematics and Advanced
+       Applications (eds. de Castro, A. B., Gómez, D., Quintela, P. & Salgado, P.)
+       97–118 (Springer, 2006). https://doi.org/10.1007/978-3-540-34288-5_6
        http://www.sam.math.ethz.ch/~hiptmair/Seminars/OSCINT/INO06.pdf
 
     Examples
@@ -863,7 +868,6 @@ def tau2iw(gf_tau, beta, n_pole=None, moments=None, fourier=tau2iw_ft_lin):
     --------
     tau2iw_ft_lin : Back-end: Fourier integration using Filon's method
     tau2iw_dft : Back-end: plain implementation using Riemann sum.
-
     pole_gf_from_tau : Function handling the fitting of `gf_tau`
 
     Examples
@@ -1002,7 +1006,7 @@ def izp2tau(izp, gf_izp, tau, beta, moments=(1.,)):
 
     Fourier transformation of a fermionic Padé Green's function to
     imaginary-time domain.
-    We assume a Hermitian Green's function `gf_iw`, i.e. :math:`G(-iω_n) = G^*(iω_n)`,
+    We assume a Hermitian Green's function `gf_izp`, i.e. :math:`G(-iω_n) = G^*(iω_n)`,
     which is the case for commutator Green's functions :math:`G_{AB}(τ) = ⟨A(τ)B⟩`
     with :math:`A = B^†`. The Fourier transform `gf_tau` is then real.
 
@@ -1010,7 +1014,7 @@ def izp2tau(izp, gf_izp, tau, beta, moments=(1.,)):
 
     Parameters
     ----------
-    izp, gf_iw : (N_izp) float np.ndarray
+    izp, gf_izp : (N_izp) float np.ndarray
         Positive **fermionic** Padé frequencies :math:`iz_p` and the Green's
         function at specified frequencies.
     tau : (N_tau) float np.ndarray
@@ -1019,7 +1023,7 @@ def izp2tau(izp, gf_izp, tau, beta, moments=(1.,)):
     beta : float
         The inverse temperature :math:`beta = 1/k_B T`.
     moments : (m) float array_like, optional
-        High-frequency moments of `gf_iw`.
+        High-frequency moments of `gf_izp`.
 
     Returns
     -------
@@ -1154,8 +1158,8 @@ def tt2z_lin(tt, gf_t, z):
 
     :math:`G(t)` is approximated by a linear spline.
     The function currently requires an equidistant `tt`.
-    Information on oscillatory integrations can be found e.g. in [filon1928]_
-    and [iserles]_.
+    Information on oscillatory integrations can be found e.g. in [filon1930]_
+    and [iserles2006]_.
 
     Parameters
     ----------
@@ -1189,10 +1193,13 @@ def tt2z_lin(tt, gf_t, z):
 
     References
     ----------
-    .. [filon1928] L.N. Filon, On a quadrature formula for trigonometric integrals,
-       Proc. Roy. Soc. Edinburgh 49 (1928) 38-47.
-    .. [iserles] A. Iserles, S.P. Nørsett, and S. Olver, Highly oscillatory
-       quadrature: The story so far,
+    .. [filon1930] Filon, L. N. G. III.—On a Quadrature Formula for
+       Trigonometric Integrals. Proc. Roy. Soc. Edinburgh 49, 38–47 (1930).
+       https://doi.org/10.1017/S0370164600026262
+    .. [iserles2006] Iserles, A., Nørsett, S. P. & Olver, S. Highly Oscillatory
+       Quadrature: The Story so Far. in Numerical Mathematics and Advanced
+       Applications (eds. de Castro, A. B., Gómez, D., Quintela, P. & Salgado, P.)
+       97–118 (Springer, 2006). https://doi.org/10.1007/978-3-540-34288-5_6
        http://www.sam.math.ethz.ch/~hiptmair/Seminars/OSCINT/INO06.pdf
 
     """
@@ -1380,6 +1387,10 @@ def tau2izp(gf_tau, beta, izp, moments=None, occ=False, weight=None):
     moments : (m) float array_like, optional
         High-frequency moments of `gf_iw`. If none are given, the first moment
         is chosen to remove the discontinuity at :math:`τ=0^{±}`.
+    occ : float, optional
+        If given, fix occupation of Green's function to `occ`. (default: False)
+    weight : (..., N_tau) float np.ndarray, optional
+        Weight the values of `gf_tau`, can be provided to include uncertainty.
 
     Returns
     -------
@@ -1389,7 +1400,6 @@ def tau2izp(gf_tau, beta, izp, moments=None, occ=False, weight=None):
     See Also
     --------
     tau2iw : Fourier transform to fermionic Matsubara frequencies.
-
     pole_gf_from_tau : Function handling the fitting of `gf_tau`
 
     Notes
