@@ -1,4 +1,3 @@
-# coding: utf8
 """Tests for Green's functions and related functions.
 
 TODO: use accuracy of *integrate.quad* for *pytest.approx*
@@ -19,6 +18,7 @@ from hypothesis_gufunc.gufunc import gufunc_args
 
 from .context import gftool as gt
 
+HAS_QUAD = gt.precision.HAS_QUAD
 
 nonneg_float = st.floats(min_value=0.)
 pos_float = st.floats(min_value=0., exclude_min=True)
@@ -858,13 +858,31 @@ def test_bethe_derivative_2(z, D):
     assert np.allclose(gf_d1, fct_d1(z))
 
 
-@given(z=st.complex_numbers(max_magnitude=1e4),
-       D=st.floats(min_value=1e-2, max_value=1e2))
+@given(z=st.complex_numbers(max_magnitude=1e4 if HAS_QUAD else 1e3),
+       D=st.floats(min_value=1e-2 if HAS_QUAD else 1e-1, max_value=1e2))
 def test_bethe_inverse(z, D):
     """Check inverse."""
-    assume(z.imag != 0)  # Gf have poles on real axis
+    if HAS_QUAD:
+        assume(z.imag != 0)  # Gf have poles on real axis
+        approx = pytest.approx
+    else:
+        assume(abs(z.imag) > 1e-8)
+        approx = partial(pytest.approx, rel=1e-4)
     gf = gt.lattice.bethe.gf_z(z, half_bandwidth=D)
-    assert gt.lattice.bethe.gf_z_inv(gf, half_bandwidth=D) == pytest.approx(z)
+    assert gt.lattice.bethe.gf_z_inv(gf, half_bandwidth=D) == approx(z)
+
+
+@pytest.mark.parametrize("D", [1/3, 1.0, 2.0])
+@pytest.mark.parametrize("center", [-1/3, 0, 0.5])
+def test_bethe_retarded(D, center):
+    """Compare retarded-time Green's function via Laplace transform."""
+    tt = np.linspace(0, 100/D, 1500)
+    gf_ret_t = gt.lattice.bethe.gf_ret_t(tt, half_bandwidth=D, center=center)
+    # use large shift to make Laplace transform good
+    ww = np.linspace(-2*D, 2*D, num=501) + 10j
+    gf_ft = gt.fourier.tt2z(tt, gf_ret_t, z=ww)
+    gf_ww = gt.bethe_gf_z(ww - D*center, half_bandwidth=D)
+    assert np.allclose(gf_ft, gf_ww, rtol=1e-4, atol=1e-5)
 
 
 def test_hilbert_equals_integral():
